@@ -40,6 +40,7 @@ if os.path.exists(os.path.join(possible_topdir, 'barbican', '__init__.py')):
 
 
 from barbican.common import config
+from barbican import i18n as u
 from barbican import queue
 from barbican.queue import keystone_listener
 
@@ -52,17 +53,19 @@ def fail(returncode, e):
     sys.exit(returncode)
 
 
-if __name__ == '__main__':
+def main():
     try:
         config.setup_remote_pydev_debug()
+
+        CONF = config.CONF
+
         # Import and configure logging.
-        log.setup('barbican')
+        log.setup(CONF, 'barbican')
 
         LOG = log.getLogger(__name__)
-        LOG.info("Booting up Barbican Keystone listener node...")
+        LOG.info(u._LI("Booting up Barbican Keystone listener node..."))
 
         # Queuing initialization
-        CONF = config.CONF
         queue.init(CONF)
 
         if getattr(getattr(CONF, queue.KS_NOTIFICATIONS_GRP_NAME), 'enable'):
@@ -71,6 +74,10 @@ if __name__ == '__main__':
                 keystone_listener.MessageServer(CONF)
             ).wait()
         else:
-            LOG.info("Exiting as Barbican Keystone listener is not enabled...")
+            LOG.info(u._LI("Exiting as Barbican Keystone listener"
+                           " is not enabled..."))
     except RuntimeError as e:
         fail(1, e)
+
+if __name__ == '__main__':
+    sys.exit(main())
