@@ -24,6 +24,7 @@ import uuid
 from oslo_log import log
 import pecan
 import six
+from six.moves.urllib import parse
 
 from barbican.common import config
 from barbican import i18n as u
@@ -35,6 +36,13 @@ CONF = config.CONF
 # Current API version
 API_VERSION = 'v1'
 
+# Added here to remove cyclic dependency.
+# In barbican.model.models module SecretType.OPAQUE was imported from
+# barbican.plugin.interface.secret_store which introduces a cyclic dependency
+# if `secret_store` plugin needs to use db model classes. So moving shared
+# value to another common python module which is already imported in both.
+SECRET_TYPE_OPAQUE = "opaque"
+
 
 def _do_allow_certain_content_types(func, content_types_list=[]):
     # Allows you to bypass pecan's content-type restrictions
@@ -55,9 +63,30 @@ def allow_all_content_types(f):
     return _do_allow_certain_content_types(f, mimetypes.types_map.values())
 
 
+def get_base_url_from_request():
+    """Derive base url from wsgi request if CONF.host_href is not set
+
+    Use host.href as base URL if its set in barbican.conf.
+    If its not set, then derives value from wsgi request. WSGI request uses
+    HOST header or HTTP_X_FORWARDED_FOR header (in case of proxy) for host +
+    port part of its url. Proxies can also set HTTP_X_FORWARDED_PROTO header
+    for indicating http vs https.
+
+    Some of unit tests does not have pecan context that's why using request
+    attr check on pecan instance.
+    """
+    if not CONF.host_href and hasattr(pecan.request, 'url'):
+        p_url = parse.urlsplit(pecan.request.url)
+        base_url = '%s://%s' % (p_url.scheme, p_url.netloc)
+        return base_url
+    else:  # when host_href is set or flow is not within wsgi request context
+        return CONF.host_href
+
+
 def hostname_for_refs(resource=None):
     """Return the HATEOAS-style return URI reference for this service."""
-    ref = ['{base}/{version}'.format(base=CONF.host_href, version=API_VERSION)]
+    base_url = get_base_url_from_request()
+    ref = ['{base}/{version}'.format(base=base_url, version=API_VERSION)]
     if resource:
         ref.append('/' + resource)
     return ''.join(ref)
@@ -154,3 +183,8 @@ def get_class_for(module_name, class_name):
 
 def generate_uuid():
     return str(uuid.uuid4())
+
+
+def is_multiple_backends_enabled():
+    secretstore_conf = config.get_module_config('secretstore')
+    return secretstore_conf.secretstore.enable_multiple_secret_stores
