@@ -279,6 +279,7 @@ def build_ffi():
     # FUNCTIONS
     ffi.cdef(textwrap.dedent("""
     CK_RV C_Initialize(void *);
+    CK_RV C_Finalize(void *);
     CK_RV C_OpenSession(CK_SLOT_ID, CK_FLAGS, void *, CK_NOTIFY,
                         CK_SESSION_HANDLE *);
     CK_RV C_CloseSession(CK_SESSION_HANDLE);
@@ -316,25 +317,15 @@ def build_ffi():
     CK_RV C_Verify(CK_SESSION_HANDLE, CK_BYTE_PTR, CK_ULONG, CK_BYTE_PTR,
                    CK_ULONG);
     CK_RV C_GenerateRandom(CK_SESSION_HANDLE, CK_BYTE_PTR, CK_ULONG);
+    CK_RV C_SeedRandom(CK_SESSION_HANDLE, CK_BYTE_PTR, CK_ULONG);
     """))
     return ffi
 
 
-class P11CryptoPluginKeyException(exception.BarbicanException):
-    message = u._("More than one key found for label")
-
-
-class P11CryptoPluginException(exception.BarbicanException):
-    message = u._("General exception")
-
-
-class P11CryptoKeyHandleException(exception.BarbicanException):
-    message = u._("No key handle was found")
-
-
 class PKCS11(object):
     def __init__(self, library_path, login_passphrase, rw_session, slot_id,
-                 ffi=None, algorithm='CKM_AES_GCM'):
+                 ffi=None, algorithm='CKM_AES_GCM',
+                 seed_random_buffer=None):
         self.ffi = ffi or build_ffi()
         self.lib = self.ffi.dlopen(library_path)
         rv = self.lib.C_Initialize(self.ffi.NULL)
@@ -353,6 +344,8 @@ class PKCS11(object):
 
         # Validate configuration and RNG
         session = self.get_session()
+        if seed_random_buffer is not None:
+            self._seed_random(session, seed_random_buffer)
         self._rng_self_test(session)
         self.return_session(session)
 
@@ -394,24 +387,24 @@ class PKCS11(object):
         rv = self.lib.C_FindObjectsFinal(session)
         self._check_error(rv)
         if count[0] > 1:
-            raise P11CryptoPluginKeyException()
+            raise exception.P11CryptoPluginKeyException()
         return key
 
     def encrypt(self, key, pt_data, session):
-        iv = self._generate_random(self.noncesize, session)
-        ck_mechanism = self._build_gcm_mechanism(iv)
+        ck_mechanism = self._build_gcm_mechanism()
         rv = self.lib.C_EncryptInit(session, ck_mechanism.mech, key)
         self._check_error(rv)
 
         pt_len = len(pt_data)
-        ct_len = self.ffi.new("CK_ULONG *", pt_len + self.gcmtagsize)
+        ct_len = self.ffi.new("CK_ULONG *", pt_len + self.gcmtagsize * 2)
         ct = self.ffi.new("CK_BYTE[{0}]".format(ct_len[0]))
         rv = self.lib.C_Encrypt(session, pt_data, pt_len, ct, ct_len)
         self._check_error(rv)
 
+        # HSM-generated IVs are appended to the end of the ciphertext
         return {
-            "iv": self.ffi.buffer(iv)[:],
-            "ct": self.ffi.buffer(ct, ct_len[0])[:]
+            "iv": self.ffi.buffer(ct, ct_len[0])[-self.gcmtagsize:],
+            "ct": self.ffi.buffer(ct, ct_len[0])[:-self.gcmtagsize]
         }
 
     def decrypt(self, key, iv, ct_data, session):
@@ -436,18 +429,19 @@ class PKCS11(object):
         # between 1 and blocksize, and that there are that many consecutive
         # bytes of that value at the end. If all of that is true, we remove
         # the found padding.
+        last_byte = ord(pt[-1:])
         if len(iv) == self.blocksize and \
            (len(pt) % self.blocksize) == 0 and \
-           1 <= ord(pt[-1]) <= self.blocksize and \
-           pt.endswith(pt[-1] * ord(pt[-1])):
-            pt = pt[:-(ord(pt[-1]))]
+           1 <= last_byte <= self.blocksize and \
+           pt.endswith(pt[-1:] * last_byte):
+            pt = pt[:-last_byte]
 
         return pt
 
     def generate_key(self, key_length, session, key_label=None,
                      encrypt=False, sign=False, wrap=False, master_key=False):
         if not encrypt and not sign and not wrap:
-            raise P11CryptoPluginException()
+            raise exception.P11CryptoPluginException()
         if master_key and not key_label:
             raise ValueError(u._("key_label must be set for master_keys"))
 
@@ -566,14 +560,26 @@ class PKCS11(object):
         rv = self.lib.C_DestroyObject(session, obj_handle)
         self._check_error(rv)
 
+    def finalize(self):
+        rv = self.lib.C_Finalize(self.ffi.NULL)
+        self._check_error(rv)
+
     def _check_error(self, value):
         if value != CKR_OK:
-            # TODO(jkf) Expand error handling to raise different exceptions
-            # for notable errors we want to handle programmatically
-            raise P11CryptoPluginException(u._(
-                "HSM returned response code: {hex_value} {code}").format(
-                    hex_value=hex(value),
-                    code=ERROR_CODES.get(value, 'CKR_????')))
+            code = ERROR_CODES.get(value, 'CKR_????')
+            hex_code = "{hex} {code}".format(hex=hex(value), code=code)
+
+            if code == 'CKR_TOKEN_NOT_PRESENT':
+                raise exception.P11CryptoTokenException(slot_id=self.slot_id)
+
+            raise exception.P11CryptoPluginException(u._(
+                "HSM returned response code: {code}").format(code=hex_code))
+
+    def _seed_random(self, session, seed_random_buffer):
+        """Call the C_SeedRandom() function with the seed_random data"""
+        buf = self.ffi.new("CK_BYTE[]", seed_random_buffer.encode())
+        rv = self.lib.C_SeedRandom(session, buf, len(seed_random_buffer))
+        self._check_error(rv)
 
     def _generate_random(self, length, session):
         buf = self.ffi.new("CK_BYTE[{0}]".format(length))
@@ -635,17 +641,20 @@ class PKCS11(object):
     def _rng_self_test(self, session):
         test_random = self.generate_random(100, session)
         if test_random == b'\x00' * 100:
-            raise P11CryptoPluginException(
+            raise exception.P11CryptoPluginException(
                 u._("Apparent RNG self-test failure."))
 
-    def _build_gcm_mechanism(self, iv):
-        iv_len = len(iv)
+    def _build_gcm_mechanism(self, iv=None):
         mech = self.ffi.new("CK_MECHANISM *")
         mech.mechanism = self.algorithm
         gcm = self.ffi.new("CK_AES_GCM_PARAMS *")
-        gcm.pIv = iv
-        gcm.ulIvLen = iv_len
-        gcm.ulIvBits = iv_len * 8
+
+        if iv:
+            iv_len = len(iv)
+            gcm.pIv = iv
+            gcm.ulIvLen = iv_len
+            gcm.ulIvBits = iv_len * 8
+
         gcm.ulTagBits = self.gcmtagsize * 8
         mech.parameter = gcm
         mech.parameter_len = 48
