@@ -18,6 +18,7 @@ import os
 import mock
 from oslo_utils import timeutils
 
+from barbican.api.controllers import secrets
 from barbican.common import validators
 from barbican.model import models
 from barbican.model import repositories
@@ -34,7 +35,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
     def test_can_create_new_secret_one_step(self):
         resp, secret_uuid = create_secret(
             self.app,
-            payload=b'not-encrypted',
+            payload='not-encrypted',
             content_type='text/plain'
         )
 
@@ -63,7 +64,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         self.assertIsNotNone(project)
 
     def test_can_create_new_secret_with_payload_just_under_max(self):
-        large_payload = b'A' * (validators.DEFAULT_MAX_SECRET_BYTES - 8)
+        large_payload = 'A' * (validators.DEFAULT_MAX_SECRET_BYTES - 8)
         resp, _ = create_secret(
             self.app,
             payload=large_payload,
@@ -73,7 +74,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(201, resp.status_int)
 
     def test_creating_new_secret_with_oversized_payload_should_fail(self):
-        oversized_payload = b'A' * (validators.DEFAULT_MAX_SECRET_BYTES + 10)
+        oversized_payload = 'A' * (validators.DEFAULT_MAX_SECRET_BYTES + 10)
         resp, _ = create_secret(
             self.app,
             payload=oversized_payload,
@@ -140,7 +141,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
         # Create a normal secret with the TransportKey
         resp, secret_uuid = create_secret(
             self.app,
-            payload=b'not-encrypted',
+            payload='not-encrypted',
             content_type='text/plain',
             transport_key_id=transport_key_id
         )
@@ -160,7 +161,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
     def test_new_secret_fails_with_invalid_transport_key_ref(self):
         resp, _ = create_secret(
             self.app,
-            payload=b'superdupersecret',
+            payload='superdupersecret',
             content_type='text/plain',
             transport_key_id="non_existing_transport_key_id",
             transport_key_needed="true",
@@ -171,7 +172,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
     def test_new_secret_w_unsupported_content_type_should_fail(self):
         resp, _ = create_secret(
             self.app,
-            payload=b'something_here',
+            payload='something_here',
             content_type='bogus_content_type',
             expect_errors=True
         )
@@ -186,7 +187,7 @@ class WhenTestingSecretsResource(utils.BarbicanAPIBaseTestCase):
                                                       content_type=None):
         resp, _ = create_secret(
             self.app,
-            payload=b'lOtfqHaUUpe6NqLABgquYQ==',
+            payload='lOtfqHaUUpe6NqLABgquYQ==',
             content_type=content_type,
             content_encoding=encoding,
             expect_errors=True
@@ -271,6 +272,16 @@ class WhenGettingSecretsList(utils.BarbicanAPIBaseTestCase):
         self.assertNotIn('previous', get_resp.json)
         self.assertNotIn('next', get_resp.json)
 
+    def test_bad_date_filter_results_in_400(self):
+        params = {'expiration': 'bogus'}
+        get_resp = self.app.get('/secrets/', params, expect_errors=True)
+        self.assertEqual(400, get_resp.status_int)
+
+    def test_bad_sorting_results_in_400(self):
+        params = {'sort': 'bogus'}
+        get_resp = self.app.get('/secrets/', params, expect_errors=True)
+        self.assertEqual(400, get_resp.status_int)
+
 
 class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
@@ -289,7 +300,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
             '/secrets/{0}'.format(secret_uuid), headers=headers
         )
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body)
+        self.assertEqual(payload, get_resp.body.decode('utf-8'))
 
     def test_get_secret_payload_with_pecan_default_accept_header(self):
         payload = 'a very interesting string'
@@ -306,7 +317,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
             '/secrets/{0}/payload'.format(secret_uuid), headers=headers
         )
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body)
+        self.assertEqual(payload, get_resp.body.decode('utf-8'))
 
     def test_get_secret_payload_with_blank_accept_header(self):
         payload = 'a very interesting string'
@@ -323,7 +334,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
             '/secrets/{0}/payload'.format(secret_uuid), headers=headers
         )
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body)
+        self.assertEqual(payload, get_resp.body.decode('utf-8'))
 
     def test_get_secret_payload_with_no_accept_header(self):
         payload = 'a very interesting string'
@@ -340,7 +351,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
             '/secrets/{0}/payload'.format(secret_uuid), headers=headers
         )
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(payload, get_resp.body)
+        self.assertEqual(payload, get_resp.body.decode('utf-8'))
 
     def test_get_secret_is_decoded_for_binary(self):
         payload = 'a123'
@@ -356,7 +367,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         get_resp = self.app.get(
             '/secrets/{0}'.format(secret_uuid), headers=headers
         )
-        decoded = 'k]\xb7'
+        decoded = b'k]\xb7'
 
         self.assertEqual(decoded, get_resp.body)
 
@@ -368,6 +379,18 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         )
         self.assertEqual(404, get_resp.status_int)
 
+    def test_returns_404_on_get_payload_when_no_payload(self):
+        resp, secret_uuid = create_secret(self.app)
+        headers = {
+            'Accept': 'text/plain',
+        }
+        get_resp = self.app.get(
+            '/secrets/{0}/payload'.format(secret_uuid),
+            headers=headers,
+            expect_errors=True
+        )
+        self.assertEqual(404, get_resp.status_int)
+
     def test_returns_404_on_get_with_bad_uuid(self):
         get_resp = self.app.get(
             '/secrets/98c876d9-aaac-44e4-8ea8-441932962b05X',
@@ -416,7 +439,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
         )
 
         self.assertEqual(200, get_resp.status_int)
-        self.assertEqual(message, get_resp.body)
+        self.assertEqual(message, get_resp.body.decode('utf-8'))
 
     def test_put_binary_secret(self):
         resp, secret_uuid = create_secret(
@@ -449,7 +472,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(201, resp.status_int)
 
-        payload = base64.b64encode('I had something for this')
+        payload = base64.b64encode(b'I had something for this')
         put_resp = self.app.put(
             '/secrets/{0}'.format(secret_uuid),
             payload,
@@ -479,7 +502,7 @@ class WhenGettingPuttingOrDeletingSecret(utils.BarbicanAPIBaseTestCase):
 
         self.assertEqual(201, resp.status_int)
 
-        payload = base64.b64encode('I had something for this')
+        payload = base64.b64encode(b'I had something for this')
         put_resp = self.app.put(
             '/secrets/{0}'.format(secret_uuid),
             payload,
@@ -704,6 +727,94 @@ class WhenPerformingUnallowedOperations(utils.BarbicanAPIBaseTestCase):
         self.assertEqual(405, resp.status_int)
 
 
+class WhenValidatingDateFilters(utils.BarbicanAPIBaseTestCase):
+
+    def setUp(self):
+        super(WhenValidatingDateFilters, self).setUp()
+        self.controller = secrets.SecretsController()
+
+    def test_validates_plain_timestamp(self):
+        date_filter = '2016-01-01T00:00:00'
+        self.assertTrue(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validates_gt_and_lt_timestamps(self):
+        date_filter = 'gt:2016-01-01T00:00:00,lt:2016-12-31T00:00:00'
+        self.assertTrue(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validates_gte_and_lte_timestamps(self):
+        date_filter = 'gte:2016-01-01T00:00:00,lte:2016-12-31T00:00:00'
+        self.assertTrue(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_two_plain_timestamps(self):
+        date_filter = '2016-01-01T00:00:00,2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_two_gt_timestamps(self):
+        date_filter = 'gt:2016-01-01T00:00:00,gt:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_two_lt_timestamps(self):
+        date_filter = 'lt:2016-01-01T00:00:00,lt:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_two_gte_timestamps(self):
+        date_filter = 'gte:2016-01-01T00:00:00,gte:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_two_lte_timestamps(self):
+        date_filter = 'lte:2016-01-01T00:00:00,lte:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_plain_and_gte_timestamps(self):
+        date_filter = '2016-01-01T00:00:00,gte:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+        date_filter = 'gte:2016-01-01T00:00:00,2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_plain_and_lte_timestamps(self):
+        date_filter = '2016-01-01T00:00:00,lte:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+        date_filter = 'lte:2016-01-01T00:00:00,2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_gt_and_gte_timestamps(self):
+        date_filter = 'gt:2016-01-01T00:00:00,gte:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_lt_and_lte_timestamps(self):
+        date_filter = 'lt:2016-01-01T00:00:00,lte:2016-01-02T00:00:00'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+    def test_validation_fails_with_bogus_timestamp(self):
+        date_filter = 'bogus'
+        self.assertFalse(self.controller._is_valid_date_filter(date_filter))
+
+
+class WhenValidatingSortFilters(utils.BarbicanAPIBaseTestCase):
+
+    def setUp(self):
+        super(WhenValidatingSortFilters, self).setUp()
+        self.controller = secrets.SecretsController()
+
+    def test_validates_name_sorting(self):
+        sorting = 'name'
+        self.assertTrue(self.controller._is_valid_sorting(sorting))
+
+    def test_validation_fails_for_bogus_attribute(self):
+        sorting = 'bogus'
+        self.assertFalse(self.controller._is_valid_sorting(sorting))
+
+    def test_validation_fails_for_duplicate_keys(self):
+        sorting = 'name,name:asc'
+        self.assertFalse(self.controller._is_valid_sorting(sorting))
+
+    def test_validation_fails_for_too_many_colons(self):
+        sorting = 'name:asc:foo'
+        self.assertFalse(self.controller._is_valid_sorting(sorting))
+
+
 # ----------------------- Helper Functions ---------------------------
 def create_secret(app, name=None, algorithm=None, bit_length=None, mode=None,
                   expiration=None, payload=None, content_type=None,
@@ -738,4 +849,4 @@ def create_secret(app, name=None, algorithm=None, bit_length=None, mode=None,
         secret_ref = resp.json.get('secret_ref', '')
         _, created_uuid = os.path.split(secret_ref)
 
-    return (resp, created_uuid)
+    return resp, created_uuid
