@@ -28,6 +28,9 @@ testr run --subunit | subunit-trace --no-failure-debug -f
 retval=$?
 testr slowest
 
+coverage combine
+coverage report -m
+
 # run the tests in parallel
 SKIP=^\(\?\!\.\*\(ProjectQuotasPagingTestCase\|QuotaEnforcementTestCase\|ListingCAsTestCase\|ProjectCATestCase\|GlobalPreferredCATestCase\|CertificateAuthoritiesTestCase\)\)
 testr init
@@ -35,4 +38,7 @@ testr run $SKIP --parallel --subunit | subunit-trace --no-failure-debug -f
 retval=$(($retval || $?))
 testr slowest
 
+coverage combine
+coverage report -m
+
 exit $retval
